==> config-api-0.3.11-sources.jar: org/wildfly/swarm/config/remoting/SASLSecurity.java <==
package org.wildfly.swarm.config.remoting;

import org.wildfly.swarm.config.runtime.Implicit;
import org.wildfly.swarm.config.runtime.ResourceType;
import org.wildfly.swarm.config.runtime.ModelNodeBinding;
import java.util.List;
import org.wildfly.swarm.config.runtime.Subresource;
/**
 * The "sasl" element contains the SASL authentication configuration for this connector.
 */
@ResourceType("security")
@Implicit
public class SASLSecurity<T extends SASLSecurity> {

	private String key;
	private List<String> includeMechanisms = new java.util.ArrayList<>();
	private List<String> qop = new java.util.ArrayList<>();
	private Boolean reuseSession;
	private Boolean serverAuth;
	private List<String> strength = new java.util.ArrayList<>();
	private SASLSecurityResources subresources = new SASLSecurityResources();
	private PolicySASLPolicy policySaslPolicy;

	public SASLSecurity() {
		this.key = "sasl";
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * The optional nested "include-mechanisms" element contains a whitelist of allowed SASL mechanism names. No mechanisms will be allowed which are not present in this list.
	 */
	@ModelNodeBinding(detypedName = "include-mechanisms")
	public List<String> includeMechanisms() {
		return this.includeMechanisms;
	}

	/**
	 * The optional nested "include-mechanisms" element contains a whitelist of allowed SASL mechanism names. No mechanisms will be allowed which are not present in this list.
	 */
	@SuppressWarnings("unchecked")
	public SASLSecurity includeMechanisms(List<String> value) {
		this.includeMechanisms = value;
		return (SASLSecurity) this;
	}

	/**
	 * The optional nested "include-mechanisms" element contains a whitelist of allowed SASL mechanism names. No mechanisms will be allowed which are not present in this list.
	 */
	public SASLSecurity includeMechanismsValue(String value) {
		this.includeMechanisms.add(value);
		return (SASLSecurity) this;
	}

	/**
	 * The optional nested "qop" element contains a list of quality-of-protection values, in decreasing order of preference.
	 */
	@ModelNodeBinding(detypedName = "qop")
	public List<String> qop() {
		return this.qop;
	}

	/**
	 * The optional nested "qop" element contains a list of quality-of-protection values, in decreasing order of preference.
	 */
	@SuppressWarnings("unchecked")
	public SASLSecurity qop(List<String> value) {
		this.qop = value;
		return (SASLSecurity) this;
	}

	/**
	 * The optional nested "qop" element contains a list of quality-of-protection values, in decreasing order of preference.
	 */
	public SASLSecurity qopValue(String value) {
		this.qop.add(value);
		return (SASLSecurity) this;
	}

	/**
	 * The optional nested "reuse-session" boolean element specifies whether or not the server should attempt to reuse previously authenticated session information.  The mechanism may or may not support such reuse, and other factors may also prevent it.
	 */
	@ModelNodeBinding(detypedName = "reuse-session")
	public Boolean reuseSession() {
		return this.reuseSession;
	}

	/**
	 * The optional nested "reuse-session" boolean element specifies whether or not the server should attempt to reuse previously authenticated session information.  The mechanism may or may not support such reuse, and other factors may also prevent it.
	 */
	@SuppressWarnings("unchecked")
	public SASLSecurity reuseSession(Boolean value) {
		this.reuseSession = value;
		return (SASLSecurity) this;
	}

	/**
	 * The optional nested "server-auth" boolean element specifies whether the server should authenticate to the client.  Not all mechanisms may support this setting.
	 */
	@ModelNodeBinding(detypedName = "server-auth")
	public Boolean serverAuth() {
		return this.serverAuth;
	}

	/**
	 * The optional nested "server-auth" boolean element specifies whether the server should authenticate to the client.  Not all mechanisms may support this setting.
	 */
	@SuppressWarnings("unchecked")
	public SASLSecurity serverAuth(Boolean value) {
		this.serverAuth = value;
		return (SASLSecurity) this;
	}

	/**
	 * The optional nested "strength" element contains a list of cipher strength values, in decreasing order of preference.
	 */
	@ModelNodeBinding(detypedName = "strength")
	public List<String> strength() {
		return this.strength;
	}

	/**
	 * The optional nested "strength" element contains a list of cipher strength values, in decreasing order of preference.
	 */
	@SuppressWarnings("unchecked")
	public SASLSecurity strength(List<String> value) {
		this.strength = value;
		return (SASLSecurity) this;
	}

	/**
	 * The optional nested "strength" element contains a list of cipher strength values, in decreasing order of preference.
	 */
	public SASLSecurity strengthValue(String value) {
		this.strength.add(value);
		return (SASLSecurity) this;
	}

	public SASLSecurityResources subresources() {
		return this.subresources;
	}

	/**
	 * Add all org.wildfly.swarm.config.remoting.Property objects to this subresource
	 * @return this
	 * @param value List of org.wildfly.swarm.config.remoting.Property objects.
	 */
	@SuppressWarnings("unchecked")
	public SASLSecurity propertys(
			List<org.wildfly.swarm.config.remoting.Property> value) {
		this.subresources.propertys = value;
		return (SASLSecurity) this;
	}

	/**
	 * Add the org.wildfly.swarm.config.remoting.Property object to the list of subresources
	 * @param value The org.wildfly.swarm.config.remoting.Property to add
	 * @return this
	 */
	@SuppressWarnings("unchecked")
	public SASLSecurity property(Property value) {
		this.subresources.propertys.add(value);
		return (SASLSecurity) this;
	}

	/**
	 * Create and configure a org.wildfly.swarm.config.remoting.Property object to the list of subresources
	 * @param key The key for the org.wildfly.swarm.config.remoting.Property resource
	 * @param config The org.wildfly.swarm.config.remoting.PropertyConfigurator to use
	 * @return this
	 */
	@SuppressWarnings("unchecked")
	public SASLSecurity property(String childKey, PropertyConfigurator config) {
		org.wildfly.swarm.config.remoting.Property child = new org.wildfly.swarm.config.remoting.Property(
				childKey);
		if (config != null) {
			config.configure(child);
		}
		property(child);
		return (SASLSecurity) this;
	}

	/**
	 * Create and configure a org.wildfly.swarm.config.remoting.Property object to the list of subresources
	 * @param key The key for the org.wildfly.swarm.config.remoting.Property resource
	 * @return this
	 */
	@SuppressWarnings("unchecked")
	public SASLSecurity property(String childKey) {
		property(childKey, null);
		return (SASLSecurity) this;
	}

	/**
	 * Child mutators for SASLSecurity
	 */
	public class SASLSecurityResources {
		/**
		 * Properties supported by the underlying provider. The property name is inferred from the last element of the properties address.
		 */
		private List<org.wildfly.swarm.config.remoting.Property> propertys = new java.util.ArrayList<>();

		/**
		 * Get the list of org.wildfly.swarm.config.remoting.Property resources
		 * @return the list of resources
		 */
		@Subresource
		public List<Property> propertys() {
			return this.propertys;
		}
	}

	/**
	 * The policy configuration.
	 */
	@Subresource
	public PolicySASLPolicy policySaslPolicy() {
		return this.policySaslPolicy;
	}

	/**
	 * The policy configuration.
	 */
	@SuppressWarnings("unchecked")
	public SASLSecurity policySaslPolicy(PolicySASLPolicy value) {
		this.policySaslPolicy = value;
		return (SASLSecurity) this;
	}
}

==> config-api-0.3.12-sources.jar: org/wildfly/swarm/config/remoting/SASLSecurity.java <==
package org.wildfly.swarm.config.remoting;

import org.wildfly.swarm.config.runtime.Implicit;
import org.wildfly.swarm.config.runtime.ResourceType;
import org.wildfly.swarm.config.runtime.ModelNodeBinding;
import java.util.List;
import org.wildfly.swarm.config.runtime.Subresource;
/**
 * The "sasl" element contains the SASL authentication configuration for this connector.
 */
@ResourceType("security")
@Implicit
public class SASLSecurity<T extends SASLSecurity> {

	private String key;
	private List<String> includeMechanisms;
	private List<String> qop;
	private Boolean reuseSession;
	private Boolean serverAuth;
	private List<String> strength;
	private SASLSecurityResources subresources = new SASLSecurityResources();
	private PolicySASLPolicy policySaslPolicy;

	public SASLSecurity() {
		this.key = "sasl";
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * The optional nested "include-mechanisms" element contains a whitelist of allowed SASL mechanism names. No mechanisms will be allowed which are not present in this list.
	 */
	@ModelNodeBinding(detypedName = "include-mechanisms")
	public List<String> includeMechanisms() {
		return this.includeMechanisms;
	}

	/**
	 * The optional nested "include-mechanisms" element contains a whitelist of allowed SASL mechanism names. No mechanisms will be allowed which are not present in this list.
	 */
	@SuppressWarnings("unchecked")
	public T includeMechanisms(List<String> value) {
		this.includeMechanisms = value;
		return (T) this;
	}

	/**
	 * The optional nested "include-mechanisms" element contains a whitelist of allowed SASL mechanism names. No mechanisms will be allowed which are not present in this list.
	 */
	public T includeMechanism(String value) {
		if (this.includeMechanisms == null) {
			this.includeMechanisms = new java.util.ArrayList<>();
		}
		this.includeMechanisms.add(value);
		return (T) this;
	}

	/**
	 * The optional nested "qop" element contains a list of quality-of-protection values, in decreasing order of preference.
	 */
	@ModelNodeBinding(detypedName = "qop")
	public List<String> qop() {
		return this.qop;
	}

	/**
	 * The optional nested "qop" element contains a list of quality-of-protection values, in decreasing order of preference.
	 */
	@SuppressWarnings("unchecked")
	public T qop(List<String> value) {
		this.qop = value;
		return (T) this;
	}

	/**
	 * The optional nested "qop" element contains a list of quality-of-protection values, in decreasing order of preference.
	 */
	public T qop(String value) {
		if (this.qop == null) {
			this.qop = new java.util.ArrayList<>();
		}
		this.qop.add(value);
		return (T) this;
	}

	/**
	 * The optional nested "reuse-session" boolean element specifies whether or not the server should attempt to reuse previously authenticated session information.  The mechanism may or may not support such reuse, and other factors may also prevent it.
	 */
	@ModelNodeBinding(detypedName = "reuse-session")
	public Boolean reuseSession() {
		return this.reuseSession;
	}

	/**
	 * The optional nested "reuse-session" boolean element specifies whether or not the server should attempt to reuse previously authenticated session information.  The mechanism may or may not support such reuse, and other factors may also prevent it.
	 */
	@SuppressWarnings("unchecked")
	public T reuseSession(Boolean value) {
		this.reuseSession = value;
		return (T) this;
	}

	/**
	 * The optional nested "server-auth" boolean element specifies whether the server should authenticate to the client.  Not all mechanisms may support this setting.
	 */
	@ModelNodeBinding(detypedName = "server-auth")
	public Boolean serverAuth() {
		return this.serverAuth;
	}

	/**
	 * The optional nested "server-auth" boolean element specifies whether the server should authenticate to the client.  Not all mechanisms may support this setting.
	 */
	@SuppressWarnings("unchecked")
	public T serverAuth(Boolean value) {
		this.serverAuth = value;
		return (T) this;
	}

	/**
	 * The optional nested "strength" element contains a list of cipher strength values, in decreasing order of preference.
	 */
	@ModelNodeBinding(detypedName = "strength")
	public List<String> strength() {
		return this.strength;
	}

	/**
	 * The optional nested "strength" element contains a list of cipher strength values, in decreasing order of preference.
	 */
	@SuppressWarnings("unchecked")
	public T strength(List<String> value) {
		this.strength = value;
		return (T) this;
	}

	/**
	 * The optional nested "strength" element contains a list of cipher strength values, in decreasing order of preference.
	 */
	public T strength(String value) {
		if (this.strength == null) {
			this.strength = new java.util.ArrayList<>();
		}
		this.strength.add(value);
		return (T) this;
	}

	public SASLSecurityResources subresources() {
		return this.subresources;
	}

	/**
	 * Add all org.wildfly.swarm.config.remoting.Property objects to this subresource
	 * @return this
	 * @param value List of org.wildfly.swarm.config.remoting.Property objects.
	 */
	@SuppressWarnings("unchecked")
	public T propertys(List<org.wildfly.swarm.config.remoting.Property> value) {
		this.subresources.propertys = value;
		return (T) this;
	}

	/**
	 * Add the org.wildfly.swarm.config.remoting.Property object to the list of subresources
	 * @param value The org.wildfly.swarm.config.remoting.Property to add
	 * @return this
	 */
	@SuppressWarnings("unchecked")
	public T property(Property value) {
		this.subresources.propertys.add(value);
		return (T) this;
	}

	/**
	 * Create and configure a org.wildfly.swarm.config.remoting.Property object to the list of subresources
	 * @param key The key for the org.wildfly.swarm.config.remoting.Property resource
	 * @param config The org.wildfly.swarm.config.remoting.PropertyConfigurator to use
	 * @return this
	 */
	@SuppressWarnings("unchecked")
	public T property(String childKey, PropertyConfigurator config) {
		org.wildfly.swarm.config.remoting.Property child = new org.wildfly.swarm.config.remoting.Property(
				childKey);
		if (config != null) {
			config.configure(child);
		}
		property(child);
		return (T) this;
	}

	/**
	 * Create and configure a org.wildfly.swarm.config.remoting.Property object to the list of subresources
	 * @param key The key for the org.wildfly.swarm.config.remoting.Property resource
	 * @return this
	 */
	@SuppressWarnings("unchecked")
	public T property(String childKey) {
		property(childKey, null);
		return (T) this;
	}

	/**
	 * Child mutators for SASLSecurity
	 */
	public class SASLSecurityResources {
		/**
		 * Properties supported by the underlying provider. The property name is inferred from the last element of the properties address.
		 */
		private List<org.wildfly.swarm.config.remoting.Property> propertys = new java.util.ArrayList<>();

		/**
		 * Get the list of org.wildfly.swarm.config.remoting.Property resources
		 * @return the list of resources
		 */
		@Subresource
		public List<Property> propertys() {
			return this.propertys;
		}
	}

	/**
	 * The policy configuration.
	 */
	@Subresource
	public PolicySASLPolicy policySaslPolicy() {
		return this.policySaslPolicy;
	}

	/**
	 * The policy configuration.
	 */
	@SuppressWarnings("unchecked")
	public T policySaslPolicy(PolicySASLPolicy value) {
		this.policySaslPolicy = value;
		return (T) this;
	}
}
